pub enum List<'parent, T> {
Cons(&'parent List<'parent, T>, T),
Nil,
}Expand description
A stack or arena-allocable append-only linked list.
Variants
Cons(&'parent List<'parent, T>, T)
A list with one more element than its parent
Nil
The base case: an empty list
Implementations
Sourceimpl<'parent, T> List<'parent, T>
impl<'parent, T> List<'parent, T>
Sourcepub fn enter<'a>(&'a self, value: T) -> List<'a, T>where
T: 'a,
pub fn enter<'a>(&'a self, value: T) -> List<'a, T>where
T: 'a,
Creates a List with one more element than self
Sourcepub fn parent(&self) -> Option<&List<'parent, T>>
pub fn parent(&self) -> Option<&List<'parent, T>>
Gets the parent element of this List (the cdr)
pub fn get_reverse(&self) -> Vec<&T>